@@ -2,9 +2,8 @@
 
 mod combinators;
 mod fs_util;
-mod parser;
+pub mod parser;
 mod shell;
 mod shell_types;
 
-pub use parser::*;
 pub use shell::*;
